@@ -1,6 +1,6 @@
 package Exception::Class;
-BEGIN {
-  $Exception::Class::VERSION = '1.31';
+{
+  $Exception::Class::VERSION = '1.37';
 }
 
 use 5.008001;
@@ -87,8 +87,8 @@ sub _make_parents {
     die
         "Class $subclass appears to be a typo as it is only specified in the 'isa' param for $child\n"
         unless exists $needs->{$subclass}
-            || $CLASSES{$subclass}
-            || keys %{"$subclass\::"};
+        || $CLASSES{$subclass}
+        || keys %{"$subclass\::"};
 
     foreach my $c ( @{ $needs->{$subclass}{parents} } ) {
 
@@ -153,7 +153,7 @@ EOPERL
 
         $code
             .= "sub Fields { return (\$_[0]->SUPER::Fields, "
-            . join( ", ", map {"'$_'"} @fields )
+            . join( ", ", map { "'$_'" } @fields )
             . ") }\n\n";
 
         foreach my $field (@fields) {
@@ -199,7 +199,7 @@ sub Classes { sort keys %Exception::Class::CLASSES }
 
 # ABSTRACT: A module that allows you to declare real exception classes in Perl
 
-
+__END__
 
 =pod
 
@@ -209,7 +209,7 @@ Exception::Class - A module that allows you to declare real exception classes in
 
 =head1 VERSION
 
-version 1.31
+version 1.37
 
 =head1 SYNOPSIS
 
@@ -229,26 +229,38 @@ version 1.31
           alias  => 'throw_fields',
       },
   );
+  use Scalar::Util qw( blessed );
+  use Try::Tiny;
 
-  # try
-  eval { MyException->throw( error => 'I feel funny.' ) };
-
-  my $e;
-
-  # catch
-  if ( $e = Exception::Class->caught('MyException') ) {
-      warn $e->error, "\n", $e->trace->as_string, "\n";
-      warn join ' ', $e->euid, $e->egid, $e->uid, $e->gid, $e->pid, $e->time;
-
-      exit;
-  }
-  elsif ( $e = Exception::Class->caught('ExceptionWithFields') ) {
-      $e->quixotic ? do_something_wacky() : do_something_sane();
-  }
-  else {
-      $e = Exception::Class->caught();
-      ref $e ? $e->rethrow : die $e;
+  try {
+      MyException->throw( error => 'I feel funny.' );
   }
+  catch {
+      die $_ unless blessed $_ && $_->can('rethrow');
+
+      if ( $_->isa('Exception::Class') ) {
+          warn $_->error, "\n", $_->trace->as_string, "\n";
+          warn join ' ', $_->euid, $_->egid, $_->uid, $_->gid, $_->pid, $_->time;
+
+          exit;
+      }
+      elsif ( $_->isa('ExceptionWithFields') ) {
+          if ( $_->quixotic ) {
+              handle_quixotic_exception();
+          }
+          else {
+              handle_non_quixotic_exception();
+          }
+      }
+      else {
+          $_->rethrow;
+      }
+  };
+
+  # without Try::Tiny
+
+  eval { ... };
+  if ( my $e = Exception::Class->caught() ) { ... }
 
   # use an alias - without parens subroutine name is checked at
   # compile time
@@ -256,6 +268,12 @@ version 1.31
 
 =head1 DESCRIPTION
 
+B<RECOMMENDATION 1>: If you are writing modern Perl code with L<Moose> or
+L<Moo> I highly recommend using L<Throwable> instead of this module.
+
+B<RECOMMENDATION 2>: Whether or not you use L<Throwable>, you should use
+L<Try::Tiny>.
+
 Exception::Class allows you to declare exception hierarchies in your
 modules in a "Java-esque" manner.
 
@@ -361,7 +379,33 @@ hierarchies and will die if it finds one.  It also detects missing
 links in a chain, for example if you declare Bar to be a subclass of
 Foo and never declare Foo.
 
-=head1 Catching Exceptions
+=head1 L<Try::Tiny>
+
+If you are interested in adding try/catch/finally syntactic sugar to your code
+then I recommend you check out L<Try::Tiny>. This is a great module that helps
+you ignore some of the weirdness with C<eval> and C<$@>. Here's an example of
+how the two modules work together:
+
+  use Exception::Class ( 'My::Exception' );
+  use Scalar::Util qw( blessed );
+  use Try::Tiny;
+
+  try {
+      might_throw();
+  }
+  catch {
+      if ( blessed $_ && $_->isa('My::Exception') ) {
+          handle_it();
+      }
+      else {
+          die $_;
+      }
+  };
+
+Note that you B<cannot> use C<< Exception::Class->caught() >> with
+L<Try::Tiny>.
+
+=head1 Catching Exceptions Without L<Try::Tiny>
 
 C<Exception::Class> provides some syntactic sugar for catching
 exceptions in a safe manner:
@@ -401,8 +445,8 @@ C<isa()> in that class like this:
 
  sub isa { shift->rethrow }
 
-Of course, this only works if you always call 
-C<< Exception::Class->caught() >> after an C<eval>.
+Of course, this only works if you always call C<< Exception::Class->caught()
+>> after an C<eval>.
 
 =head1 USAGE RECOMMENDATION
 
@@ -460,22 +504,6 @@ note that if you simply define a subclass via the normal Perl method
 of setting C<@ISA> or C<use base>, then your subclass will not be
 included.
 
-=head1 OTHER EXCEPTION MODULES (try/catch syntax)
-
-If you are interested in adding try/catch/finally syntactic sugar to
-your code then I recommend you check out U. Arun Kumar's C<Error.pm>
-module, which implements this syntax.  It also includes its own base
-exception class, C<Error::Simple>.
-
-If you would prefer to use the L<Exception::Class::Base> class
-included with this module, you'll have to add this to your code
-somewhere:
-
-  push @Exception::Class::Base::ISA, 'Error'
-      unless Exception::Class::Base->isa('Error');
-
-It's a hack but apparently it works.
-
 =head1 SUPPORT
 
 Please submit bugs to the CPAN RT system at
@@ -505,18 +533,13 @@ L<http://www.urth.org/~autarch/fs-donation.html>
 
 =head1 AUTHOR
 
-  Dave Rolsky <autarch@urth.org>
+Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
-This is free software, licensed under:
-
-  The Artistic License 2.0
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
